import http.client
import daemon
from time import sleep
from datetime import datetime

TIMEOUT: float = 1
TESTDOMAINS: list[str] = ["cscherr.de", "debian.org", "cloudflare.com"]
SLEEPTIME: int = 300 # 5 minutes

def check_net() -> tuple[bool, str]:
    statuses: list[bool] = []
    fmsg: str = ""
    for domain in TESTDOMAINS:
        status, msg = reachable(domain)
        statuses.append(status)
        fmsg += (f"{domain:60s} {msg}\n")

    overall = False
    for s in statuses:
        overall |= s
    return overall, fmsg

def reachable(domain: str) -> tuple[bool, str]:
    try:
        conn = http.client.HTTPSConnection(domain, timeout=TIMEOUT)
        conn.request("GET", "/")
        r = conn.getresponse()
        conn.close()
        return True, r.status.__str__()
    except Exception as e:
        return False, e.__str__()

def monitor():
    while True:
        try:
            b, msg = check_net()
            if not b: 
                print(f":FAILURE AT {datetime.now()}:")
                print(msg)
            sleep(SLEEPTIME)
        except Exception as e:
            print(e)

if __name__ == "__main__":
    print("executing as normal script")
    monitor()

with daemon.DaemonContext():
    print("entering daemon mode")
    monitor()
